==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm2015/lib/ChaikinOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { ChaikinOscillatorIndicatorStrategy } from "./ChaikinOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let ChaikinOscillatorIndicator = /*@__PURE__*/ (() => {
    class ChaikinOscillatorIndicator extends StrategyBasedIndicator {
        get_up() {
            return new ChaikinOscillatorIndicatorStrategy();
        }
        get up() {
            return this.get_up();
        }
        get_u2() {
            return ChaikinOscillatorIndicator.$;
        }
        get u2() {
            return this.get_u2();
        }
        get shortPeriod() {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.vb));
        }
        set shortPeriod(a) {
            this.h(ChaikinOscillatorIndicator.vb, a);
        }
        ux() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.va));
        }
        set longPeriod(a) {
            this.h(ChaikinOscillatorIndicator.va, a);
        }
        uu() {
            return this.longPeriod;
        }
    }
    ChaikinOscillatorIndicator.$t = markType(ChaikinOscillatorIndicator, 'ChaikinOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    ChaikinOscillatorIndicator.vb = StrategyBasedIndicator.u9(3, ChaikinOscillatorIndicator.$);
    ChaikinOscillatorIndicator.va = StrategyBasedIndicator.u5(10, ChaikinOscillatorIndicator.$);
    return ChaikinOscillatorIndicator;
})();

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm2015/lib/ChaikinOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { ChaikinOscillatorIndicatorStrategy } from "./ChaikinOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let ChaikinOscillatorIndicator = /*@__PURE__*/ (() => {
    class ChaikinOscillatorIndicator extends StrategyBasedIndicator {
        get_yy() {
            return new ChaikinOscillatorIndicatorStrategy();
        }
        get yy() {
            return this.get_yy();
        }
        get_zb() {
            return ChaikinOscillatorIndicator.$;
        }
        get zb() {
            return this.get_zb();
        }
        get shortPeriod() {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.zk));
        }
        set shortPeriod(a) {
            this.h(ChaikinOscillatorIndicator.zk, a);
        }
        y6() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.zj));
        }
        set longPeriod(a) {
            this.h(ChaikinOscillatorIndicator.zj, a);
        }
        y3() {
            return this.longPeriod;
        }
    }
    ChaikinOscillatorIndicator.$t = markType(ChaikinOscillatorIndicator, 'ChaikinOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    ChaikinOscillatorIndicator.zk = StrategyBasedIndicator.zi(3, ChaikinOscillatorIndicator.$);
    ChaikinOscillatorIndicator.zj = StrategyBasedIndicator.ze(10, ChaikinOscillatorIndicator.$);
    return ChaikinOscillatorIndicator;
})();
